@@ -560,7 +560,7 @@ class TestFlexibleBoolean(TestField):
 class TestDateTime(TestField):
     def setUp(self):
         super(TestDateTime, self).setUp()
-        self.dt = datetime.datetime(1955, 11, 5, tzinfo=iso8601.iso8601.Utc())
+        self.dt = datetime.datetime(1955, 11, 5, tzinfo=iso8601.iso8601.UTC)
         self.field = fields.DateTimeField()
         self.coerce_good_values = [(self.dt, self.dt),
                                    (_utils.isotime(self.dt), self.dt)]
@@ -573,7 +573,7 @@ class TestDateTime(TestField):
             '1955-11-05T18:00:00Z',
             self.field.stringify(
                 datetime.datetime(1955, 11, 5, 18, 0, 0,
-                                  tzinfo=iso8601.iso8601.Utc())))
+                                  tzinfo=iso8601.iso8601.UTC)))
 
     def test_get_schema(self):
         self.assertEqual({'type': ['string'], 'format': 'date-time',
